==> haskell-chell-quickcheck-0.2.5.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell-quickcheck
version: 0.2.5.1
id: chell-quickcheck-0.2.5.1-4IWslT7z85y1rWoHBicCOl
key: chell-quickcheck-0.2.5.1-4IWslT7z85y1rWoHBicCOl
license: MIT
maintainer: John Millikin <john@john-millikin.com>
homepage: https://john-millikin.com/software/chell/
synopsis: QuickCheck support for the Chell testing library
category: Testing
author: John Millikin <john@john-millikin.com>
exposed: True
indefinite: False
exposed-modules:
    Test.Chell.QuickCheck
abi: 61f0945bbc17b8bdd3e51ee7a72ee3d8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/chell-quickcheck-0.2.5.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/chell-quickcheck-0.2.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/chell-quickcheck-0.2.5.1
hs-libraries: HSchell-quickcheck-0.2.5.1-4IWslT7z85y1rWoHBicCOl
depends:
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
    chell-0.4.0.2-FO01XI75y101ONTIw6iKP9
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
abi-depends: QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             chell-0.4.0.2-FO01XI75y101ONTIw6iKP9=9bf562a9f10beec6496b1502de35eba7
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
haddock-interfaces: /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-quickcheck-0.2.5.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell-quickcheck
version: 0.2.5.1
id: chell-quickcheck-0.2.5.1-9CqvWSdZvQU5hKQF2Pi0fr
key: chell-quickcheck-0.2.5.1-9CqvWSdZvQU5hKQF2Pi0fr
license: MIT
maintainer: John Millikin <john@john-millikin.com>
homepage: https://john-millikin.com/software/chell/
synopsis: QuickCheck support for the Chell testing library
category: Testing
author: John Millikin <john@john-millikin.com>
exposed: True
indefinite: False
exposed-modules:
    Test.Chell.QuickCheck
abi: 3e4b43b43012faac155938cb148b593e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/chell-quickcheck-0.2.5.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/chell-quickcheck-0.2.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/chell-quickcheck-0.2.5.1
hs-libraries: HSchell-quickcheck-0.2.5.1-9CqvWSdZvQU5hKQF2Pi0fr
depends:
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
    chell-0.4.0.2-IBQv0u4QHDwGOZdD3GqAGa
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
abi-depends: QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             chell-0.4.0.2-IBQv0u4QHDwGOZdD3GqAGa=1d15f515791a84462b457fef958611e5
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
haddock-interfaces: /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
